@@ -1,6 +1,4 @@
-from rdflib.plugin import register, Serializer
-register("json-ld", Serializer, "rdflib_jsonld.serializer", "JsonLDSerializer")
-__version__ = "2.10.0"
+__version__ = "2.12.0"
 
 from .common import *
 from .profiles import OntDoc, Prof, VocPub, NMPF, PROFILES, RDF_MEDIA_TYPES
