@@ -1,7 +1,7 @@
 import collections
 from itertools import chain
 from jinja2 import Environment, FileSystemLoader
-from rdflib import SDO, SKOS, OWL, URIRef, RDF, PROF, Literal, XSD, Graph, Namespace, FOAF, Graph
+from rdflib import SDO, SKOS, OWL, URIRef, RDF, PROF, Literal, XSD, Namespace, FOAF, Graph
 
 from pylode.common import TEMPLATES_DIR
 
@@ -460,11 +460,7 @@ class BaseProfile:
         if self.METADATA.get("repository") is not None:
             g.add((uri, SDO.codeRepository, repository))
 
-        # make sure the json-ld serializer is registered
-        from rdflib.plugin import register, Serializer
-        register('json-ld', Serializer, 'rdflib_jsonld.serializer', 'JsonLDSerializer')
-
-        return g.serialize(format="json-ld").decode("utf-8")
+        return g.serialize(format="json-ld")
 
     def _make_agent_link(self, name, url=None, email=None, affiliation=None):
         if self.outputformat == "md":
@@ -534,7 +530,7 @@ class BaseProfile:
                 email = str(o).split("/")[-1].split("#")[-1]  # remove base URI leaving only email address
             elif p in [SDO.memberOf, SDO.affiliation]:
                 for p2, o2 in self.G.predicate_objects(subject=o):
-                    if p2 in [FOAF.homepage, SDO.identifier, SDO.url]:  # TODO: split homepage form IDs, cater for rdfs:seeAlso
+                    if p2 in [FOAF.homepage, SDO.identifier, SDO.url]:  # TODO: split homepage from IDs, cater for rdfs:seeAlso
                         org_url = str(o2)
                     elif p2 in [FOAF.name, SDO.name]:
                         org_name = str(o2)
