@@ -1,4 +1,5 @@
-from pylode.common import VERSION, STYLE_DIR, TEMPLATES_DIR
+from pylode import __version__
+from pylode.common import STYLE_DIR, TEMPLATES_DIR
 import collections
 from os import path
 from rdflib import URIRef, BNode, Literal
@@ -11,34 +12,32 @@ from pylode.profiles.base import BaseProfile
 
 
 class Prof(BaseProfile):
-    def __init__(self, g, source_info, outputformat="html", include_css=False, default_language="en", get_curies_online=False):
-        super().__init__(g, source_info, outputformat=outputformat, include_css=include_css, get_curies_online=False, default_language=default_language)
+    def __init__(
+            self,
+            g,
+            source_info,
+            outputformat="html",
+            include_css=False,
+            default_language="en",
+            use_curies_stored=True,
+            get_curies_online=False
+    ):
+        super().__init__(
+            g,
+            source_info,
+            outputformat=outputformat,
+            include_css=include_css,
+            use_curies_stored=use_curies_stored,
+            get_curies_online=get_curies_online,
+            default_language=default_language)
         self.RESOURCE_DESCRIPTORS = collections.OrderedDict()
 
     def _load_template(self, template_file):
         return Environment(loader=FileSystemLoader(join(TEMPLATES_DIR, "prof"))).get_template(template_file)
 
-    def _make_formatted_uri(self, uri):
-        # set display to CURIE
-        short = self._get_curie(uri)
-        # if the URI base is within the default namespace of this ontology
-        #   use the fragment URI
-        # else
-        #   use the given URI
-        uri_base = self._get_namespace_from_uri(uri)
-        link = None
-        if uri_base == self.METADATA.get("default_namespace"):
-            if self.RESOURCE_DESCRIPTORS.get(uri):
-                link = "[{}]({})".format(self.RESOURCE_DESCRIPTORS[uri]["default_prefLabel"], self.RESOURCE_DESCRIPTORS[uri]["fid"]) \
-                    if self.outputformat == "md" \
-                    else '<a href="#{}">{}</a>'.format(self.RESOURCE_DESCRIPTORS[uri]["fid"], self.RESOURCE_DESCRIPTORS[uri]["default_prefLabel"])
-
-        if link is None:
-            link = "[{}]({})".format(short, uri) \
-                if self.outputformat == "md" \
-                else '<a href="{}">{}</a>'.format(uri, short)
-
-        return link
+    # use parent class - i.e. no overriding
+    # def _make_formatted_uri(self, uri):
+    #     pass
 
     def _expand_graph(self):
         # label
@@ -198,7 +197,7 @@ class Prof(BaseProfile):
                     if type(o) == Literal:
                         self.METADATA[agent_type].add(str(o))
                     else:  # Blank Node or URI
-                        self.METADATA[agent_type].add(self._make_agent_html(o))
+                        self.METADATA[agent_type].add(self._make_agent(o))
 
                 if p == PROF.isProfileOf:
                     self.METADATA["profiles"].add(str(o))
@@ -262,7 +261,7 @@ class Prof(BaseProfile):
             resource_descriptors=self.RESOURCE_DESCRIPTORS,
             namespaces=self._make_namespaces(),
             css=css,
-            pylode_version=VERSION
+            pylode_version=__version__
         )
 
     def generate_document(self):
