@@ -61,6 +61,20 @@ RDF_MEDIA_TYPES = [
     'application/n-triples'
 ]
 HTML_MEDIA_TYPE = "text/html"
+MOD_PROFILE = Profile(
+    "http://www.isibang.ac.in/ns/mod/1.4",
+    "Metadata for Ontology Description and Publication (MOD)",
+    "A vocabulary to describe and publish ontologies",
+    RDF_MEDIA_TYPES + [HTML_MEDIA_TYPE, "text/markdown"],
+    HTML_MEDIA_TYPE,
+    languages=["en"],
+    default_language="en",
+    is_profile_of=[
+        "https://www.w3.org/TR/owl2-rdf-based-semantics/",
+        "http://purl.org/dc/terms/",
+        "https://www.w3.org/TR/vocab-dcat/"
+    ]
+)
 PROF_PROFILE = Profile(
     "https://www.w3.org/TR/dx-prof/",
     "The Profiles Vocabulary",
@@ -104,6 +118,17 @@ ONT_DOC_PROFILE = Profile(
     default_language="en",
     is_profile_of=["https://www.w3.org/TR/owl2-rdf-based-semantics/"]
 )
+NMPF_PROFILE = Profile(
+    "https://w3id.org/profile/nmpf",
+    "Ireland's National Marine Planning Framework Ontology Documentation Profile",
+    "OWL Classes and Properties as well as additional SKOS, Dublin Core Terms and schema.org annotation "
+    "properties to be used to document ontologies.",
+    [HTML_MEDIA_TYPE, "text/markdown"],
+    HTML_MEDIA_TYPE,
+    languages=["en"],
+    default_language="en",
+    is_profile_of=["https://www.w3.org/TR/owl2-rdf-based-semantics/"]
+)
 SKOS_PROFILE = Profile(
     "https://www.w3.org/TR/skos-reference/",
     "Simple Knowledge Organization System (SKOS)",
@@ -127,20 +152,10 @@ VOC_PUB_PROFILE = Profile(
     is_profile_of=["https://www.w3.org/TR/skos-reference/"]
 )
 
-# MOD_PROFILE = Profile(
-#     "http://www.isibang.ac.in/ns/mod#MetadataForOntologyDescriptionAndPublication",
-#     "Metadata for Ontology Description and Publication (MOD)",
-#     "To describe the vocabularies, e.g., ontology, classification, metadata, etc.",
-#     RDF_MEDIA_TYPES + [HTML_MEDIA_TYPE, "text/markdown"],
-#     HTML_MEDIA_TYPE,
-#     languages=["en"],
-#     default_language="en",
-#     is_profile_of=["https://www.w3.org/TR/owl2-rdf-based-semantics/", "http://purl.org/dc/terms/"]
-# )
-
 PROFILES = {
     "prof": PROF_PROFILE,
     "ontdoc": ONT_DOC_PROFILE,
     "vocpub": VOC_PUB_PROFILE,
-    # "modp": MOD_PROFILE
-}
\ No newline at end of file
+    "nmpf": NMPF_PROFILE,
+    "mod": MOD_PROFILE,
+}
